package envoy.event;

import envoy.data.Message;

/**
 * Project: <strong>envoy-common</strong><br>
 * File: <strong>MessageStatusChangeEvent.java</strong><br>
 * Created: <strong>6 Jan 2020</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @since Envoy Common v0.2-alpha
 */
public class MessageStatusChangeEvent implements Event<Message.MessageStatus> {

	private final long					messageId;
	private final Message.MessageStatus	messageStatus;

	/**
	 * Initializes a {@link MessageStatusChangeEvent}.
	 *
	 * @param messageId     the ID of the {@link Message} this event is related to
	 * @param messageStatus the status of the {@link Message} this event is related
	 *                      to
	 * @since Envoy Common v0.2-alpha
	 */
	public MessageStatusChangeEvent(long messageId, Message.MessageStatus messageStatus) {
		this.messageId		= messageId;
		this.messageStatus	= messageStatus;
	}

	/**
	 * @return the status of the {@link Message} this event is related to
	 * @since Envoy Common v0.2-alpha
	 */
	@Override
	public Message.MessageStatus get() { return messageStatus; }

	/**
	 * @return the ID of the {@link Message} this event is related to
	 * @since Envoy Common v0.2-alpha
	 */
	public long getMessageId() { return messageId; }
}
